==> tts_espeak_V1.43.03_2010-05-25_6_i686_debian-lenny.tar.gz: tts_espeak_V1.43.03_2010-05-25_6_i686_debian-lenny/www/config.php <==
<?
#Active CDR statistics :
$enable_record_to_cdr=false;


#Common Languages en variantes
#http://www.w3.org/International/articles/language-tags/
#
# language-Script-REGION-variant-extension-privateuse
#
#The entries in the registry follow certain conventions with regard to upper and 
#lowercasing - for example, language tags are lower case, alphabetic region subtags
#are upper case, and script tags begin with an initial capital. This is only a 
#convention! When you use these subtags you are free to do as you like.


#default tts engine is the first in this tts array :
$tts=array();
#espeak_begin
$tts["espeak"]= array(
      "name" => "espeak",
      "call"  => "/usr/local/bin/espeak",
      "options" => array(' -v $voice -b1 ',' -f $filename', '--stdout | /usr/local/bin/ffmpeg -i - -ar 8000 $filename.$iformat' ),
      "voices" => array(
        'en'  => array(
                          'type'=>'male',
                          'desc'=>'English Male',
                          'voptions' => array ('voice' => 'en')
                        ),
        'en-us'  => array(
                          'type'=>'male',
                          'desc'=>'English from United States Male',
                          'voptions' => array ('voice' => 'en-us')
                        ),
        'en-uk'  => array(
                          'type'=>'male',
                          'desc'=>'English from United Kingdom Male',
                          'voptions' => array ('voice' => 'en-uk')
                        ),
        'en-scotland'  => array(
                          'type'=>'male',
                          'desc'=>'English Scottish Male',
                          'voptions' => array ('voice' => 'en-scotland')
                        ),
        'en-n'  => array(
                          'type'=>'male',
                          'desc'=>'English from Lancashire Male',
                          'voptions' => array ('voice' => 'en-n')
                        ),
        'en-wi'  => array(
                          'type'=>'male',
                          'desc'=>'English from West Indies Male',
                          'voptions' => array ('voice' => 'en-wi')
                        ),
        'en-wm'  => array(
                          'type'=>'male',
                          'desc'=>'English from West Midlands Male',
                          'voptions' => array ('voice' => 'en-wm')
                        ),
        'en-rp'  => array(
                          'type'=>'male',
                          'desc'=>'English Received Pronunciation (Oxford) Male',
                          'voptions' => array ('voice' => 'en-rp')
                        ),
        'fr'  => array(
                          'type'=>'male',
                          'desc'=>'French Male',
                          'voptions' => array ('voice' => 'fr')
                        ),
        'fr-be'  => array(
                          'type'=>'male',
                          'desc'=>'French from Belgium Male',
                          'voptions' => array ('voice' => 'fr-be')
                        ),
        'es'  => array(
                          'type'=>'male',
                          'desc'=>'Spanish Castilian Male',
                          'voptions' => array ('voice' => 'es')
                        ),
        'es-la'=> array(
                          'type'=>'male',
                          'desc'=>'Spanish from Latin America Male',
                          'voptions' => array ('voice' => 'es-la')
                        ),
        'it'  => array(
                          'type'=>'male',
                          'desc'=>'Italian Male',
                          'voptions' => array ('voice' => 'it')
                        ),
        'ca'  => array(
                          'type'=>'male',
                          'desc'=>'Catalan, Valencian Male',
                          'voptions' => array ('voice' => 'ca')
                        ),
        'de'  => array(
                          'type'=>'male',
                          'desc'=>'German Male',
                          'voptions' => array ('voice' => 'de')
                        ),
        'af'  => array(
                          'type'=>'male',
                          'desc'=>'Afrikaans Male',
                          'voptions' => array ('voice' => 'af')
                        ),
        'cs'  => array(
                          'type'=>'male',
                          'desc'=>'Czech Male',
                          'voptions' => array ('voice' => 'cs')
                        ),
        'da'  => array(
                          'type'=>'male',
                          'desc'=>'Danish Male',
                          'voptions' => array ('voice' => 'da')
                        ),
        'el'  => array(
                          'type'=>'male',
                          'desc'=>'Greek, Modern (1453-) Male',
                          'voptions' => array ('voice' => 'el')
                        ),
        'eo'  => array(
                          'type'=>'male',
                          'desc'=>'Esperanto Male',
                          'voptions' => array ('voice' => 'eo')
                        ),
        'fi'  => array(
                          'type'=>'male',
                          'desc'=>'Finnish Male',
                          'voptions' => array ('voice' => 'fi')
                        ),
        'hi'  => array(
                          'type'=>'male',
                          'desc'=>'Hindi Male',
                          'voptions' => array ('voice' => 'hi')
                        ),
        'hr'  => array(
                          'type'=>'male',
                          'desc'=>'Croatian Male',
                          'voptions' => array ('voice' => 'hr')
                        ),
        'hu'  => array(
                          'type'=>'male',
                          'desc'=>'Hungarian Male',
                          'voptions' => array ('voice' => 'hu')
                        ),
        'hy'  => array(
                          'type'=>'male',
                          'desc'=>'Armenian Male',
                          'voptions' => array ('voice' => 'hy')
                        ),
        'hy-west'=> array(
                          'type'=>'male',
                          'desc'=>'Male speaking Armenian from West',
                          'voptions' => array ('voice' => 'hy-west')
                        ),
        'ku'  => array(
                          'type'=>'male',
                          'desc'=>'Kurdish Male',
                          'voptions' => array ('voice' => 'ku')
                        ),
        'la'  => array(
                          'type'=>'male',
                          'desc'=>'Latin Male',
                          'voptions' => array ('voice' => 'la')
                        ),
        'lv'  => array(
                          'type'=>'male',
                          'desc'=>'Latvian Male',
                          'voptions' => array ('voice' => 'lv')
                        ),
        'no'  => array(
                          'type'=>'male',
                          'desc'=>'Norwegian Male',
                          'voptions' => array ('voice' => 'no')
                        ),
        'pl'  => array(
                          'type'=>'male',
                          'desc'=>'Polish Male',
                          'voptions' => array ('voice' => 'pl')
                        ),
        'pt'  => array(
                          'type'=>'male',
                          'desc'=>'Portuguese Male',
                          'voptions' => array ('voice' => 'pt')
                        ),
        'pt-br'  => array(
                          'type'=>'male',
                          'desc'=>'Portuguese from Brazil Male',
                          'voptions' => array ('voice' => 'pt-br')
                        ),
        'pt-pt'  => array(
                          'type'=>'male',
                          'desc'=>'Portuguese from Portugal Male',
                          'voptions' => array ('voice' => 'pt-pt')
                        ),
        'ro'  => array(
                          'type'=>'male',
                          'desc'=>'Romanian, Moldavian, Moldovan Male',
                          'voptions' => array ('voice' => 'ro')
                        ),
        'ru'  => array(
                          'type'=>'male',
                          'desc'=>'Russian Male',
                          'voptions' => array ('voice' => 'ru')
                        ),
        'sk'  => array(
                          'type'=>'male',
                          'desc'=>'Slovak Male',
                          'voptions' => array ('voice' => 'sk')
                        ),
        'sq'  => array(
                          'type'=>'male',
                          'desc'=>'Albanian Male',
                          'voptions' => array ('voice' => 'sq')
                        ),
        'sv'  => array(
                          'type'=>'male',
                          'desc'=>'Swedish Male',
                          'voptions' => array ('voice' => 'sv')
                        ),
        'ta'  => array(
                          'type'=>'male',
                          'desc'=>'Tamil Male',
                          'voptions' => array ('voice' => 'ta')
                        ),
        'tr'  => array(
                          'type'=>'male',
                          'desc'=>'Turkish Male',
                          'voptions' => array ('voice' => 'tr')
                        ),
        'zh'  => array(
                          'type'=>'male',
                          'desc'=>'Chinese Male',
                          'voptions' => array ('voice' => 'zh')
                        ),

       ),
      "langcodes" => array(
                        'en' => array('en','en-n','en-uk','en-us','en-wi','en-rp','en-wm'),
                        'en-US' => array('en-us'),
                        'en-UK' => array('en-uk'),
                        'en-scotland' => array('en-sc'),
                        'fr'    => array('fr','fr-be'),
                        'fr-BE' => array('fr-be'),
                        'es'    => array('es','es-la'),
                        'it'    => array('it'),
                        'ca'    => array('ca'),
                        'de'    => array('de'),
                        'af'    => array('af'),
                        'cs'    => array('cs'),
                        'da'    => array('da'),
                        'el'    => array('el'),
                        'eo'    => array('eo'),
                        'fi'    => array('fi'),
                        'hi'    => array('hi'),
                        'hr'    => array('hr'),
                        'hu'    => array('hu'),
                        'hy'    => array('hy','hy-west'),
                        'ku'    => array('ku'),
                        'la'    => array('la'),
                        'lv'    => array('lv'),
                        'no'    => array('no'),
                        'pl'    => array('pl'),
                        'pt'    => array('pt','pt-pt'),
                        'pt-BR' => array('pt'),
                        'pt-PT' => array('pt-pt'),
                        'ro'    => array('ro'),
                        'ru'    => array('ru'),
                        'sk'    => array('sk'),
                        'sq'    => array('sq'),
                        'sv'    => array('sv'),
                        'ta'    => array('ta'),
                        'tr'    => array('tr'),
                        'zh'    => array('zh'),
                       ),
      "charsets" => array('UTF-8'),
      "codecs" => array('pcm'=>'pcm'),
      "iformats" => array('wav'),
      "vxiformats" => array('wav' => array('iformat'=>'wav','codec'=>'pcm')),
      "formatiscodec"=>false,
      "debugargs"=>"",
      "checks"=>array("/usr/local/bin/ffmpeg","/usr/local/bin/espeak"),
);
#espeak_end





# vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:

==> tts_espeak_V1.45.03_2011-04-04_16_i686_debian-lenny.tar.gz: tts_espeak_V1.45.03_2011-04-04_16_i686_debian-lenny/www/config.php <==
<?
#Active CDR statistics :
$enable_record_to_cdr=false;


#Common Languages en variantes
#http://www.w3.org/International/articles/language-tags/
#
# language-Script-REGION-variant-extension-privateuse
#
#The entries in the registry follow certain conventions with regard to upper and 
#lowercasing - for example, language tags are lower case, alphabetic region subtags
#are upper case, and script tags begin with an initial capital. This is only a 
#convention! When you use these subtags you are free to do as you like.


#default tts engine is the first in this tts array :
$tts=array();
#espeak_begin
$tts["espeak"]= array(
      "name" => "espeak",
      "call"  => "/usr/local/bin/espeak",
      "options" => array(' -v $voice -b1 ',' -f $filename', '--stdout | /usr/local/bin/ffmpeg -i - -ar 8000 $filename.$iformat' ),
      "voices" => array(
        'en'  => array(
                          'type'=>'male',
                          'desc'=>'English Male',
                          'voptions' => array ('voice' => 'en')
                        ),
        'en-us'  => array(
                          'type'=>'male',
                          'desc'=>'English from United States Male',
                          'voptions' => array ('voice' => 'en-us')
                        ),
        'en-uk'  => array(
                          'type'=>'male',
                          'desc'=>'English from United Kingdom Male',
                          'voptions' => array ('voice' => 'en-uk')
                        ),
        'en-scotland'  => array(
                          'type'=>'male',
                          'desc'=>'English Scottish Male',
                          'voptions' => array ('voice' => 'en-scotland')
                        ),
        'en-n'  => array(
                          'type'=>'male',
                          'desc'=>'English from Lancashire Male',
                          'voptions' => array ('voice' => 'en-n')
                        ),
        'en-wi'  => array(
                          'type'=>'male',
                          'desc'=>'English from West Indies Male',
                          'voptions' => array ('voice' => 'en-wi')
                        ),
        'en-wm'  => array(
                          'type'=>'male',
                          'desc'=>'English from West Midlands Male',
                          'voptions' => array ('voice' => 'en-wm')
                        ),
        'en-rp'  => array(
                          'type'=>'male',
                          'desc'=>'English Received Pronunciation (Oxford) Male',
                          'voptions' => array ('voice' => 'en-rp')
                        ),
        'fr'  => array(
                          'type'=>'male',
                          'desc'=>'French Male',
                          'voptions' => array ('voice' => 'fr')
                        ),
        'fr-be'  => array(
                          'type'=>'male',
                          'desc'=>'French from Belgium Male',
                          'voptions' => array ('voice' => 'fr-be')
                        ),
        'es'  => array(
                          'type'=>'male',
                          'desc'=>'Spanish Castilian Male',
                          'voptions' => array ('voice' => 'es')
                        ),
        'es-la'=> array(
                          'type'=>'male',
                          'desc'=>'Spanish from Latin America Male',
                          'voptions' => array ('voice' => 'es-la')
                        ),
        'it'  => array(
                          'type'=>'male',
                          'desc'=>'Italian Male',
                          'voptions' => array ('voice' => 'it')
                        ),
        'ca'  => array(
                          'type'=>'male',
                          'desc'=>'Catalan, Valencian Male',
                          'voptions' => array ('voice' => 'ca')
                        ),
        'de'  => array(
                          'type'=>'male',
                          'desc'=>'German Male',
                          'voptions' => array ('voice' => 'de')
                        ),
        'af'  => array(
                          'type'=>'male',
                          'desc'=>'Afrikaans Male',
                          'voptions' => array ('voice' => 'af')
                        ),
        'cs'  => array(
                          'type'=>'male',
                          'desc'=>'Czech Male',
                          'voptions' => array ('voice' => 'cs')
                        ),
        'da'  => array(
                          'type'=>'male',
                          'desc'=>'Danish Male',
                          'voptions' => array ('voice' => 'da')
                        ),
        'el'  => array(
                          'type'=>'male',
                          'desc'=>'Greek, Modern (1453-) Male',
                          'voptions' => array ('voice' => 'el')
                        ),
        'eo'  => array(
                          'type'=>'male',
                          'desc'=>'Esperanto Male',
                          'voptions' => array ('voice' => 'eo')
                        ),
        'fi'  => array(
                          'type'=>'male',
                          'desc'=>'Finnish Male',
                          'voptions' => array ('voice' => 'fi')
                        ),
        'hi'  => array(
                          'type'=>'male',
                          'desc'=>'Hindi Male',
                          'voptions' => array ('voice' => 'hi')
                        ),
        'hr'  => array(
                          'type'=>'male',
                          'desc'=>'Croatian Male',
                          'voptions' => array ('voice' => 'hr')
                        ),
        'hu'  => array(
                          'type'=>'male',
                          'desc'=>'Hungarian Male',
                          'voptions' => array ('voice' => 'hu')
                        ),
        'hy'  => array(
                          'type'=>'male',
                          'desc'=>'Armenian Male',
                          'voptions' => array ('voice' => 'hy')
                        ),
        'hy-west'=> array(
                          'type'=>'male',
                          'desc'=>'Male speaking Armenian from West',
                          'voptions' => array ('voice' => 'hy-west')
                        ),
        'ku'  => array(
                          'type'=>'male',
                          'desc'=>'Kurdish Male',
                          'voptions' => array ('voice' => 'ku')
                        ),
        'la'  => array(
                          'type'=>'male',
                          'desc'=>'Latin Male',
                          'voptions' => array ('voice' => 'la')
                        ),
        'lv'  => array(
                          'type'=>'male',
                          'desc'=>'Latvian Male',
                          'voptions' => array ('voice' => 'lv')
                        ),
        'no'  => array(
                          'type'=>'male',
                          'desc'=>'Norwegian Male',
                          'voptions' => array ('voice' => 'no')
                        ),
        'pl'  => array(
                          'type'=>'male',
                          'desc'=>'Polish Male',
                          'voptions' => array ('voice' => 'pl')
                        ),
        'pt'  => array(
                          'type'=>'male',
                          'desc'=>'Portuguese Male',
                          'voptions' => array ('voice' => 'pt')
                        ),
        'pt-br'  => array(
                          'type'=>'male',
                          'desc'=>'Portuguese from Brazil Male',
                          'voptions' => array ('voice' => 'pt-br')
                        ),
        'pt-pt'  => array(
                          'type'=>'male',
                          'desc'=>'Portuguese from Portugal Male',
                          'voptions' => array ('voice' => 'pt-pt')
                        ),
        'ro'  => array(
                          'type'=>'male',
                          'desc'=>'Romanian, Moldavian, Moldovan Male',
                          'voptions' => array ('voice' => 'ro')
                        ),
        'ru'  => array(
                          'type'=>'male',
                          'desc'=>'Russian Male',
                          'voptions' => array ('voice' => 'ru')
                        ),
        'sk'  => array(
                          'type'=>'male',
                          'desc'=>'Slovak Male',
                          'voptions' => array ('voice' => 'sk')
                        ),
        'sq'  => array(
                          'type'=>'male',
                          'desc'=>'Albanian Male',
                          'voptions' => array ('voice' => 'sq')
                        ),
        'sv'  => array(
                          'type'=>'male',
                          'desc'=>'Swedish Male',
                          'voptions' => array ('voice' => 'sv')
                        ),
        'ta'  => array(
                          'type'=>'male',
                          'desc'=>'Tamil Male',
                          'voptions' => array ('voice' => 'ta')
                        ),
        'tr'  => array(
                          'type'=>'male',
                          'desc'=>'Turkish Male',
                          'voptions' => array ('voice' => 'tr')
                        ),
        'zh'  => array(
                          'type'=>'male',
                          'desc'=>'Chinese Mandarin Male',
                          'voptions' => array ('voice' => 'zh')
                        ),
        'zh-yue'=> array(
                          'type'=>'male',
                          'desc'=>'Chinese Cantonese Male',
                          'voptions' => array ('voice' => 'zh-yue')
                        ),


       ),
      "langcodes" => array(
                        'en' => array('en','en-n','en-uk','en-us','en-wi','en-rp','en-wm'),
                        'en-US' => array('en-us'),
                        'en-UK' => array('en-uk'),
                        'en-scotland' => array('en-sc'),
                        'fr'    => array('fr','fr-be'),
                        'fr-BE' => array('fr-be'),
                        'es'    => array('es','es-la'),
                        'it'    => array('it'),
                        'ca'    => array('ca'),
                        'de'    => array('de'),
                        'af'    => array('af'),
                        'cs'    => array('cs'),
                        'da'    => array('da'),
                        'el'    => array('el'),
                        'eo'    => array('eo'),
                        'fi'    => array('fi'),
                        'hi'    => array('hi'),
                        'hr'    => array('hr'),
                        'hu'    => array('hu'),
                        'hy'    => array('hy','hy-west'),
                        'ku'    => array('ku'),
                        'la'    => array('la'),
                        'lv'    => array('lv'),
                        'no'    => array('no'),
                        'pl'    => array('pl'),
                        'pt'    => array('pt','pt-pt'),
                        'pt-BR' => array('pt'),
                        'pt-PT' => array('pt-pt'),
                        'ro'    => array('ro'),
                        'ru'    => array('ru'),
                        'sk'    => array('sk'),
                        'sq'    => array('sq'),
                        'sv'    => array('sv'),
                        'ta'    => array('ta'),
                        'tr'    => array('tr'),
                        'zh'    => array('zh'),
                        'zh-yue'=> array('zh-yue'),
                       ),
      "charsets" => array('UTF-8'),
      "codecs" => array('pcm'=>'pcm'),
      "iformats" => array('wav'),
      "vxiformats" => array('wav' => array('iformat'=>'wav','codec'=>'pcm')),
      "formatiscodec"=>false,
      "debugargs"=>"",
      "checks"=>array("/usr/local/bin/ffmpeg","/usr/local/bin/espeak"),
);
#espeak_end





# vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:
